@@ -15,7 +15,7 @@ from __future__ import absolute_import
 import collections
 import functools
 import inspect
-from io import open
+import io
 import os
 import os.path
 import re
@@ -31,7 +31,7 @@ __all__ = (
     'SassError', 'SassFunction', 'SassList', 'SassMap', 'SassNumber',
     'SassWarning', 'and_join', 'compile', 'libsass_version',
 )
-__version__ = '0.11.0'
+__version__ = '0.12.3'
 libsass_version = _sass.libsass_version
 
 
@@ -236,8 +236,9 @@ def compile_dirname(
             if s:
                 v = v.decode('UTF-8')
                 mkdirp(os.path.dirname(output_filename))
-                with open(output_filename, 'w',
-                          encoding="UTF-8") as output_file:
+                with io.open(
+                    output_filename, 'w', encoding='UTF-8', newline='',
+                ) as output_file:
                     output_file.write(v)
             else:
                 return False, v
@@ -610,35 +611,6 @@ def compile(**kwargs):
             v = v.decode('utf-8')
             if source_map_filename:
                 source_map = source_map.decode('utf-8')
-                if os.sep != '/' and os.altsep:
-                    # Libsass has a bug that produces invalid JSON string
-                    # literals which contain unescaped backslashes for
-                    # "sources" paths on Windows e.g.:
-                    #
-                    #   {
-                    #     "version": 3,
-                    #     "file": "",
-                    #     "sources": ["c:\temp\tmpj2ac07\test\b.scss"],
-                    #     "names": [],
-                    #     "mappings": "AAAA,EAAE;EAEE,WAAW"
-                    #   }
-                    #
-                    # To workaround this bug without changing libsass'
-                    # internal behavior, we replace these backslashes with
-                    # slashes e.g.:
-                    #
-                    #   {
-                    #     "version": 3,
-                    #     "file": "",
-                    #     "sources": ["c:/temp/tmpj2ac07/test/b.scss"],
-                    #     "names": [],
-                    #     "mappings": "AAAA,EAAE;EAEE,WAAW"
-                    #   }
-                    source_map = re.sub(
-                        r'"sources":\s*\[\s*"[^"]*"(?:\s*,\s*"[^"]*")*\s*\]',
-                        lambda m: m.group(0).replace(os.sep, os.altsep),
-                        source_map
-                    )
                 v = v, source_map
             return v
     elif 'dirname' in modes:
