@@ -58,8 +58,8 @@ A_EXPECTED_MAP = {
     'sources': ['test/a.scss'],
     'names': [],
     'mappings': (
-        'AAKA,AAAA,IAAI,CAAC;EAHH,gBAAgB,EAAE,KAAM,GAQzB;EALD,AAEE,'
-        'IAFE,CAEF,CAAC,CAAC;IACA,KAAK,EAAE,IAAK,GACb'
+        'AAKA,AAAA,IAAI,CAAC;EAHH,gBAAgB,EAAE,KAAK,GAQxB;EALD,AAEE,IAFE,CAEF,'
+        'CAAC,CAAC;IACA,KAAK,EAAE,IAAI,GACZ'
     ),
 }
 
@@ -596,8 +596,8 @@ class ManifestTestCase(BaseTestCase):
                     'sources': ['../test/b.scss'],
                     'names': [],
                     'mappings': (
-                        'AAAA,AACE,CADD,CACC,CAAC,CAAC;EACA,SAAS,EAAE,IAAK,'
-                        'GACjB'
+                        'AAAA,AACE,CADD,CACC,CAAC,CAAC;EACA,SAAS,EAAE,IAAI,'
+                        'GAChB'
                     ),
                 },
                 os.path.join(d, 'css', 'b.scss.css.map')
@@ -617,9 +617,9 @@ class ManifestTestCase(BaseTestCase):
                     'sources': ['../test/d.scss'],
                     'names': [],
                     'mappings': (
-                        ';AAKA,AAAA,IAAI,CAAC;EAHH,gBAAgB,EAAE,KAAM,GAQzB;'
-                        'EALD,AAEE,IAFE,CAEF,CAAC,CAAC;IACA,IAAI,EAAE,0BAA2B,'
-                        'GAClC'
+                        ';AAKA,AAAA,IAAI,CAAC;EAHH,gBAAgB,EAAE,KAAK,GAQxB;'
+                        'EALD,AAEE,IAFE,CAEF,CAAC,CAAC;IACA,IAAI,EAAE,0BAA0B,'
+                        'GACjC'
                     ),
                 },
                 os.path.join(d, 'css', 'd.scss.css.map')
@@ -643,25 +643,20 @@ class WsgiTestCase(BaseTestCase):
             client = Client(app, Response)
             r = client.get('/asdf')
             assert r.status_code == 200
-            self.assert_bytes_equal(b'/asdf', r.data)
+            self.assertEqual(b'/asdf', r.data)
             assert r.mimetype == 'text/plain'
             r = client.get('/static/a.scss.css')
             assert r.status_code == 200
-            self.assert_bytes_equal(
+            self.assertEqual(
                 b(A_EXPECTED_CSS_WITH_MAP),
-                r.data
+                r.data,
             )
             assert r.mimetype == 'text/css'
             r = client.get('/static/not-exists.sass.css')
             assert r.status_code == 200
-            self.assert_bytes_equal(b'/static/not-exists.sass.css', r.data)
+            self.assertEqual(b'/static/not-exists.sass.css', r.data)
             assert r.mimetype == 'text/plain'
 
-    def assert_bytes_equal(self, expected, actual, *args):
-        self.assertEqual(expected.replace(b'\r\n', b'\n'),
-                         actual.replace(b'\r\n', b'\n'),
-                         *args)
-
 
 class DistutilsTestCase(BaseTestCase):
 
@@ -749,7 +744,7 @@ class SasscTestCase(BaseTestCase):
             assert exit_code == 0
             assert self.err.getvalue() == ''
             assert self.out.getvalue() == ''
-            with open(tmp) as f:
+            with io.open(tmp, encoding='UTF-8', newline='') as f:
                 assert A_EXPECTED_CSS.strip() == f.read().strip()
         finally:
             os.remove(tmp)
